# A tools collection for MHD/RAW files

## Installation

A python virtual environment is advised:
```sh
# move somewhere you want your environment to be
python -m venv mhdtools
source mhdtools/bin/activate
pip install -U pip
pip install mhdtools
```

## Available tools

### `mhdview`

An MHD/RAW file 2D viewer.
See `--help` for features and options.
